/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_P8zTRe4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xzovZCcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_25i8kIBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XLivK4yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sOOVOska_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_bg7KeimG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3IVzgAfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rBX77V0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AoMvPUFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WUq27DVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LVVBI795_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JTGHXoNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5T8nsH61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DQfITy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JCZ1qrfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G2gKBOUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ze6dmtjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sbrQtDYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IRDsPsdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzQbAj7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YENB3Lqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nOwtZ4FP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QeKQDlTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ZAJbDDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WY3IyNhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ecLBW8ll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wMAAHQI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ff2NIt6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2optDNnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JPg1lWXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g1XHO7aT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ee1UGGEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_278BN7Qs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Hicr15c8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YmBzeRGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H0IEJEOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gJfMD610_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vb3BAKrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gTUXWPK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_18Hh7k2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fjhLvaZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sYd4NC98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lbmc1JBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eH6tGfhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wGRfGUn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XhAKVKdw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kWqjnxY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vtXs1l56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7pi1A0j7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_86Rdjy3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nB7lT71d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zyxKkxLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lku0hxk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zsCK6Wqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1Hp9i8ZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tOjcfWmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OaUrrKmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bqqf0bBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XklaBydk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3XZcgjKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Zijm57C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OIAZjjzg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TACHvyvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DCewnYWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oA9Z8pPu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h6wQwgiR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gU6XSia6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pz0o5ClA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bl7roO6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_umKO7Viq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mDI3KZs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4vM4cYhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nukKO33P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RD5SMJMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PoF6lTnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sSQ7NV4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_axRGJZTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9fmTRZ3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GAdbXhTd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1g22djQg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B0BY5fhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_G85gBKzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6sxe0bmm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XKTZVxiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oRMQpLQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5UoVXFCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hL2jmX6G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xg4RBRkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pizACLpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PqmvClIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CLKNqvh9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dkdh4cXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hhW81AFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_O3lorrZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XFMAWiiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_um9Xamgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AFuyhemB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wCLaKOVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JBHvVFcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_76KexZyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YDT4BfAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jv68lwrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SInA4tL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c7gHghBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dITDqUl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8BwYaVDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9u1WfHpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8iydtzk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SHuFEi3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fZlH070t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QVmGugpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cXqkAbRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W2zAh4q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tWq6NAMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sf69WUIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kgK2ECvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HRdxhAnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QHEWK9R2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J6WUoz81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TmfDHBep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GgVM9jLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_phTHHpTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CNWmONzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NR5zPqc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eIFztZDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8NsgjAtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tZBxgdvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F6CIIuZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ypdx8PSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4Ep4yxZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VMMmu8om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TNKOT6kw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iq1r0Lzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PQO63okX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ifycBbvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H0LInKQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7rw4olyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V07atBbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r9rQ945Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qh0iv3R1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UBpwVAVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D1EnvUWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BjGn5tZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cgvOONpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R11MjMCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MgoYLMeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hnDuo9eV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dMiSQShB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6803bli2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zXVkxZfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oEtbb1dS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V3puWmdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WQlx3D9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_id9xoq0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cpyai6Ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jslq7dAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FYamITiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BsnyaRwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FiHxCW0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pdfHoSND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OsQ9uYZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s1rESxhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CG1hurJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r45CpgnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7wVJgY8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UAzYjNji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AmnuL4ks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5t5cIYaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EEiCaxOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_72anlsDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oxcWVamM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pHcSUrPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FBGEm8RO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JEkpUsvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61sucHJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YDt9KTwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vDjpRPa0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YgThZRk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xhbNaB0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5qiOEgMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CNDmt0j6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Ww5Pn33j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Cb3pLE5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6eShswu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFlKlKfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZtfF0nUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ewxE3NTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PnkdZFl1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2RYu2yN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_llnX3u10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5DboYlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DBulk4cA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cfUcTL8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P4p5lmps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ccQqrDjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RLb326Tz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RmlLcgGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OVhoY027_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i1fHB6fA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EdgGyPvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MZmn6FCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zK38LQjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCyA2bOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ptf0UZRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jlevrQ9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tl665EEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eD4di4nM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lQ7fYHwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UJiuFzMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UOVsNwHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qh3jCn5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jIPwlYK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DdBPJbQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eD88OmAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RlbeS80Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0hqbOhwa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nbXWqdzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kMOX5vpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sH6asdzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mqf1Lhza_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FlU1j6yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8zYlXTY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jhoZ8MFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ac47BNNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4VO2cI2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjhEIO1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i3kI5xWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V5WzNOpM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7UAgDHu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UfCK1V8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G4kVtFQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E7volRfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mcf68jLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r9bkVIHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BB8gRNno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yXc7ddyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cQqgcdEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_82SZ2HlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_70z6sj0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q6sHDo7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_89C3ewk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_seQiQH35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UGOCgWrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i6YvsMv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rkh0TZm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XUua2WXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ThuFnS4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hm4ibtqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6VjxyOOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k94Ejdp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8CsHnOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z8DfvBmy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P57YKtbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HArYPPKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AJHkaaep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZhXskjXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TCdrfYYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LDsv3FGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4K1X6l1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TLVfFbcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5aESdSb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ayhbgctg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aMFiiiXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TeDrjgKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_669r4OWl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZQJbC4DK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ebunRpLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DrW5TBfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VDJtjn46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C1WLcOZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_l0zBc967_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ey1MCEIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kQaxngxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NHSKOdld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LfF0O1Qa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QeYsU9Ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GK42kAkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SbrbVyo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a7lSlc0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VN0vbidI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yyr4DeJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NzXTDoLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tTtnIrwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yl8JZjAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iqv7Tl5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RZZEAjTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bw6H6yhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mZNIhNdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V7QN9INA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_auq8VMWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JPq5abLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ASqvjHWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nFlHxJnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3POxgcOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2qhtC42y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mZbqoRxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1xQb9hf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ul624QST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oq2tr7Bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5nTHiObn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R08zAZVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MBDUWa1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xUyRS4vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_siEh51Uw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n8eYxXzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kEBF1zc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hv8lrj9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z5a0onEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VHwfS81u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bbnfntFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JYUhj5yX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOClTyOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eG9Lp893_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYCihrcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dDhPTzbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cx180ZdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tZDr1aJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ncIHttIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCmKyT8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EaoAnDq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WKq5n8Tj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oJupXJNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6iKWSRhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VGnZJMp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6yJcUHAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NzOTMP1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HYZssjCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K4UDzoCc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xW3FdWl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LMVc1CoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aj9xGKDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oNt8X88N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kvm3fW5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oj8C8Fix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DWQ9ozcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zo2Qz3qO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4JYQuTbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pUXEmVPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m32mDuPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Uq0XcwsW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SpvcXiak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LEG1VUKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mkbTDN29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DV0CAYLG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8DlBSwsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9HkK8sZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IubI0hkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZXjqYSYH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sUuPJ6z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5UiwPlYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Wz4U0Sqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1CJcSTnA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_X3SXNpp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KcaDshVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mjrNXrnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9i3wu2ev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o79cE5Si_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ovn0u0Ev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H7Vh6IaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WAW2npGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_faUdqUa5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jJkzBnDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_snc6lkS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZAb09Txm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a6mk20YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3lICRDpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YIPei5fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XB4MplxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Y7WswxsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jUiTk0FO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HLea3FWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zyGDTFgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RnhefgQA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aHZIRudM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jDmT6WAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qg4viDZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RFkfGR0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrZlon2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Svc98wcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wHBKH6tF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hJc5HC6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HfXplvYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XVJAJIL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q1LJzXVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F2n9fSFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lXMhDqlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JxUv0ajF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OW8R9DPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E4z4Zf8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BwnD14p1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3h3Wi7Ir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8ejGYNhf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HWNxFQq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9EVHsDoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_upAeqqDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VmqfhoC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_slRyKm85_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsnkV5tK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YilVYAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JCTuTc3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s4dkSNC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zBg7y7H1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L1mLfsFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BXeD8Eep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EFPqL7iG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ruUv1jij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u0OBiy9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rJyqAfAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Xy5wG2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wfnud3FK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZHpnWlLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bVxXHjCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sunYj1VG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xD2aJdfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EGWD1Jjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hdaWKwxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vlc8yLN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t8pU3qyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UJdlgL0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YmgOmhnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OuhkAJhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTn33Wnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x6ulymCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iT92r4ue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sc89MP4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0USEKXuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nGEqWfCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vn6arJJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PPogrYbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NOCNJl1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7I8bMUyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1kDM4T0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4MahBPoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RFPZNCYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sych993x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1C3dAk5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D5Dl0I6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hh1tb3PN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i9UrQRd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6mo5L3e1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_olLJnsDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sy66keeO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aRgbc8d5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_89JzqK2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fxRIoFXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nagqLk6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ow9jJSJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O13fy9f2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtyWJAE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I1icZ6cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DRUW7Sx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_chauK1Ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uYblZtji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_na2CLQMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IlfFVuSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8FZZv6Fe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cg2LFYrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_czjWhRxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TolvadCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ucHwe5VZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0uYYsULa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nQzqOAZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtwxzOxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XjCu0VJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ZCPRHYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UaZsGr0M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pgz7n11D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJkEM8bC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fIwMo9jV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lrvGgMti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zVgbADQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jqITEXB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IieKGfN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6UZdg3nT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qI9rWCOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_x2Swfm5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xRbqbfef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XHg4rDrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WaAfeT2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_deGkjpTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ynCh7tSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JxB9x6Hi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8JTaWSxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sgmO2Ohc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N0Gd6HCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ln2wqx49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gvBywhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uGDCrOM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TEa7ex51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eciTNOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DN8TdhTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lk6CNCPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5d9tByK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aMgnu3yG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DSHMvt3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZmvDL3Ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AjOwWSs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_axHHWgME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dXTfW897_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ofbPZUvv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JnDWdxjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hkAlh6Bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jfWXp3Qe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1QuXk2WN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zFAFq9Lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nnoK3x74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K7TUvW9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WyOhiDV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VIst5pni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KvbQ8Ldn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H9kJRyie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_icHixfCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IzbrIApp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L79fs7AN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5QSphbkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qMUBiClp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrHaSWp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IRWFBsH5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QBiCWPDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wBGX1Xvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EEJUWKM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H0azVfFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uJuKdr5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3CiN0xnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BpqDTW7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2cst7dhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mm4wg3KK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JV3PxlOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YsfYWJhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xQEriZi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jsDfF9db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bSlPDTYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AnAVIFMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0K23buCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gfhUPlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pLaqULkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iOwX99U5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3tHwTXK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qAsihnSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aD298d2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jJZcs8a5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wqHgOIYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q7G75aA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_trJ6z90N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzzEwIvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9n4zQu4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9VmjTcOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jWqNZ73T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KMsYOIpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ybba6zfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Sq9k2xqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1TEGd9G7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YfygsoHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yo0yF3ml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_igvhVmWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pq0fiBPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bhSlk7fs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_soPsQjtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vPjwuvHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0KzfHi9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m5e7Aq39_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SiERvPgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hdxZfauI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yC8LpLLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lquXcDOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IJU3i5SG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GhYqeCIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tUDVZbcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5XRiVZMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Bfy3t6Ua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bKASk7QB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sDNPnFrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3Gqoqpft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_46iclud7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dhBjdEc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UGvLs6b1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TP1M86va_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bVBKrPX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e14VlplK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tCatBsZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1eenD5T2_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_pZ3WUhIk;
  SignalLine sLine_mZznvB9g;
  SignalLine sLine_bbtBN6d2;
  SignalLine sLine_IEDzMTHs;
  SignalLine sLine_IJW2SQCq;
  SignalBiquad sBiquad_s_jV07Hw1U;
  SignalLine sLine_IG1ZO7FY;
  SignalLine sLine_o7AxAX61;
  SignalLine sLine_gvcjVKkX;
  SignalLine sLine_lr0UWOT6;
  SignalBiquad sBiquad_s_OhzeUZxJ;
  SignalLine sLine_3Oj3emeJ;
  SignalLine sLine_XyD5jdhA;
  SignalLine sLine_Cdl7DZwy;
  SignalLine sLine_MB7I3zxQ;
  SignalLine sLine_fBRRsgcS;
  SignalBiquad sBiquad_s_awuFV6wN;
  SignalLine sLine_RyQaImDd;
  SignalLine sLine_gX9RJkcz;
  SignalLine sLine_Q2MeyglR;
  SignalLine sLine_2k42GY5k;
  SignalLine sLine_sxnaJbui;
  SignalBiquad sBiquad_s_bG9H9qF9;
  SignalLine sLine_O0RVZWsg;
  SignalLine sLine_6WhiIPzd;
  SignalLine sLine_ic76AI5J;
  SignalLine sLine_bpT4wfnQ;
  SignalBiquad sBiquad_s_OoDIWNmd;
  SignalLine sLine_RyvkNURZ;
  SignalLine sLine_PG2X2Ujs;
  SignalLine sLine_DCENHStM;
  SignalLine sLine_RdcCFiRv;
  SignalLine sLine_E5ZJNniV;
  SignalBiquad sBiquad_s_LlW4Eixp;
  ControlVar cVar_P8zTRe4S;
  ControlVar cVar_xzovZCcn;
  ControlVar cVar_25i8kIBw;
  ControlVar cVar_XLivK4yo;
  ControlSlice cSlice_bg7KeimG;
  ControlVar cVar_3IVzgAfr;
  ControlVar cVar_AoMvPUFv;
  ControlIf cIf_WUq27DVH;
  ControlIf cIf_LVVBI795;
  ControlBinop cBinop_5T8nsH61;
  ControlBinop cBinop_9DQfITy5;
  ControlBinop cBinop_ze6dmtjS;
  ControlBinop cBinop_sbrQtDYp;
  ControlBinop cBinop_nzQbAj7D;
  ControlIf cIf_YENB3Lqq;
  ControlBinop cBinop_nOwtZ4FP;
  ControlBinop cBinop_QeKQDlTe;
  ControlBinop cBinop_WY3IyNhO;
  ControlBinop cBinop_ecLBW8ll;
  ControlBinop cBinop_wMAAHQI9;
  ControlVar cVar_ee1UGGEo;
  ControlIf cIf_278BN7Qs;
  ControlIf cIf_Hicr15c8;
  ControlBinop cBinop_H0IEJEOd;
  ControlBinop cBinop_gJfMD610;
  ControlBinop cBinop_18Hh7k2f;
  ControlBinop cBinop_fjhLvaZp;
  ControlBinop cBinop_Lbmc1JBT;
  ControlIf cIf_eH6tGfhm;
  ControlBinop cBinop_wGRfGUn3;
  ControlBinop cBinop_XhAKVKdw;
  ControlBinop cBinop_vtXs1l56;
  ControlBinop cBinop_7pi1A0j7;
  ControlBinop cBinop_86Rdjy3m;
  ControlVar cVar_1Hp9i8ZP;
  ControlIf cIf_tOjcfWmO;
  ControlIf cIf_OaUrrKmO;
  ControlBinop cBinop_XklaBydk;
  ControlBinop cBinop_3XZcgjKX;
  ControlBinop cBinop_TACHvyvW;
  ControlBinop cBinop_DCewnYWq;
  ControlBinop cBinop_h6wQwgiR;
  ControlIf cIf_gU6XSia6;
  ControlBinop cBinop_pz0o5ClA;
  ControlBinop cBinop_Bl7roO6W;
  ControlBinop cBinop_mDI3KZs7;
  ControlBinop cBinop_4vM4cYhn;
  ControlBinop cBinop_nukKO33P;
  ControlIf cIf_9fmTRZ3l;
  ControlSlice cSlice_1g22djQg;
  ControlVar cVar_B0BY5fhN;
  ControlSlice cSlice_XKTZVxiv;
  ControlVar cVar_oRMQpLQq;
  ControlSlice cSlice_xg4RBRkb;
  ControlVar cVar_pizACLpA;
  ControlSlice cSlice_dkdh4cXv;
  ControlVar cVar_hhW81AFE;
  ControlBinop cBinop_c7gHghBK;
  ControlBinop cBinop_8BwYaVDZ;
  ControlBinop cBinop_9u1WfHpA;
  ControlBinop cBinop_fZlH070t;
  ControlBinop cBinop_QVmGugpe;
  ControlBinop cBinop_cXqkAbRg;
  ControlBinop cBinop_W2zAh4q2;
  ControlBinop cBinop_tWq6NAMg;
  ControlVar cVar_sf69WUIs;
  ControlBinop cBinop_kgK2ECvo;
  ControlBinop cBinop_HRdxhAnK;
  ControlBinop cBinop_QHEWK9R2;
  ControlBinop cBinop_J6WUoz81;
  ControlBinop cBinop_TmfDHBep;
  ControlBinop cBinop_GgVM9jLw;
  ControlBinop cBinop_phTHHpTl;
  ControlBinop cBinop_NR5zPqc8;
  ControlVar cVar_eIFztZDJ;
  ControlVar cVar_8NsgjAtm;
  ControlBinop cBinop_iq1r0Lzd;
  ControlBinop cBinop_PQO63okX;
  ControlBinop cBinop_ifycBbvZ;
  ControlBinop cBinop_7rw4olyO;
  ControlBinop cBinop_V07atBbP;
  ControlBinop cBinop_r9rQ945Y;
  ControlBinop cBinop_Qh0iv3R1;
  ControlBinop cBinop_UBpwVAVq;
  ControlBinop cBinop_D1EnvUWR;
  ControlBinop cBinop_OsQ9uYZS;
  ControlBinop cBinop_CG1hurJ9;
  ControlBinop cBinop_r45CpgnP;
  ControlBinop cBinop_AmnuL4ks;
  ControlBinop cBinop_5t5cIYaM;
  ControlBinop cBinop_EEiCaxOC;
  ControlBinop cBinop_72anlsDw;
  ControlBinop cBinop_oxcWVamM;
  ControlBinop cBinop_pHcSUrPc;
  ControlBinop cBinop_FBGEm8RO;
  ControlBinop cBinop_61sucHJg;
  ControlVar cVar_YDt9KTwr;
  ControlVar cVar_vDjpRPa0;
  ControlVar cVar_YgThZRk0;
  ControlBinop cBinop_MFlKlKfW;
  ControlBinop cBinop_ZtfF0nUO;
  ControlBinop cBinop_ewxE3NTq;
  ControlBinop cBinop_2RYu2yN8;
  ControlBinop cBinop_llnX3u10;
  ControlBinop cBinop_L5DboYlb;
  ControlBinop cBinop_DBulk4cA;
  ControlBinop cBinop_cfUcTL8Q;
  ControlBinop cBinop_Qh3jCn5R;
  ControlBinop cBinop_DdBPJbQz;
  ControlBinop cBinop_eD88OmAW;
  ControlBinop cBinop_nbXWqdzW;
  ControlBinop cBinop_kMOX5vpr;
  ControlBinop cBinop_sH6asdzP;
  ControlBinop cBinop_Mqf1Lhza;
  ControlBinop cBinop_FlU1j6yw;
  ControlBinop cBinop_jhoZ8MFP;
  ControlBinop cBinop_4VO2cI2n;
  ControlBinop cBinop_CjhEIO1Z;
  ControlBinop cBinop_V5WzNOpM;
  ControlBinop cBinop_7UAgDHu9;
  ControlBinop cBinop_UfCK1V8n;
  ControlBinop cBinop_E7volRfl;
  ControlVar cVar_Mcf68jLk;
  ControlVar cVar_r9bkVIHD;
  ControlVar cVar_BB8gRNno;
  ControlBinop cBinop_seQiQH35;
  ControlBinop cBinop_UGOCgWrI;
  ControlBinop cBinop_i6YvsMv0;
  ControlBinop cBinop_XUua2WXk;
  ControlBinop cBinop_ThuFnS4z;
  ControlBinop cBinop_hm4ibtqu;
  ControlBinop cBinop_6VjxyOOM;
  ControlBinop cBinop_k94Ejdp9;
  ControlBinop cBinop_L8CsHnOf;
  ControlBinop cBinop_Ayhbgctg;
  ControlBinop cBinop_TeDrjgKe;
  ControlBinop cBinop_669r4OWl;
  SignalVarf sVarf_N2m7hpUP;
  SignalVarf sVarf_RVIKx4O1;
  SignalVarf sVarf_fgRza7gZ;
  ControlSlice cSlice_ebunRpLH;
  ControlVar cVar_DrW5TBfa;
  ControlVar cVar_C1WLcOZB;
  ControlIf cIf_l0zBc967;
  ControlIf cIf_ey1MCEIM;
  ControlBinop cBinop_NHSKOdld;
  ControlBinop cBinop_LfF0O1Qa;
  ControlBinop cBinop_SbrbVyo7;
  ControlBinop cBinop_a7lSlc0g;
  ControlBinop cBinop_Yyr4DeJn;
  ControlIf cIf_NzXTDoLy;
  ControlBinop cBinop_tTtnIrwo;
  ControlBinop cBinop_yl8JZjAm;
  ControlBinop cBinop_RZZEAjTM;
  ControlBinop cBinop_bw6H6yhl;
  ControlBinop cBinop_mZNIhNdk;
  ControlVar cVar_nFlHxJnt;
  ControlIf cIf_3POxgcOt;
  ControlIf cIf_2qhtC42y;
  ControlBinop cBinop_1xQb9hf2;
  ControlBinop cBinop_ul624QST;
  ControlBinop cBinop_R08zAZVO;
  ControlBinop cBinop_MBDUWa1n;
  ControlBinop cBinop_siEh51Uw;
  ControlIf cIf_n8eYxXzR;
  ControlBinop cBinop_kEBF1zc0;
  ControlBinop cBinop_Hv8lrj9s;
  ControlBinop cBinop_VHwfS81u;
  ControlBinop cBinop_bbnfntFU;
  ControlBinop cBinop_JYUhj5yX;
  ControlVar cVar_cx180ZdU;
  ControlIf cIf_tZDr1aJw;
  ControlIf cIf_ncIHttIa;
  ControlBinop cBinop_EaoAnDq8;
  ControlBinop cBinop_WKq5n8Tj;
  ControlBinop cBinop_VGnZJMp4;
  ControlBinop cBinop_6yJcUHAS;
  ControlBinop cBinop_HYZssjCv;
  ControlIf cIf_K4UDzoCc;
  ControlBinop cBinop_9xW3FdWl;
  ControlBinop cBinop_LMVc1CoL;
  ControlBinop cBinop_oNt8X88N;
  ControlBinop cBinop_kvm3fW5O;
  ControlBinop cBinop_oj8C8Fix;
  ControlIf cIf_m32mDuPC;
  ControlSlice cSlice_SpvcXiak;
  ControlVar cVar_LEG1VUKd;
  ControlSlice cSlice_8DlBSwsI;
  ControlVar cVar_9HkK8sZj;
  ControlSlice cSlice_sUuPJ6z3;
  ControlVar cVar_5UiwPlYA;
  ControlSlice cSlice_X3SXNpp3;
  ControlVar cVar_KcaDshVq;
  ControlBinop cBinop_a6mk20YJ;
  ControlBinop cBinop_YIPei5fi;
  ControlBinop cBinop_XB4MplxL;
  ControlBinop cBinop_HLea3FWs;
  ControlBinop cBinop_zyGDTFgE;
  ControlBinop cBinop_RnhefgQA;
  ControlBinop cBinop_aHZIRudM;
  ControlBinop cBinop_jDmT6WAz;
  ControlVar cVar_qg4viDZb;
  ControlBinop cBinop_RFkfGR0y;
  ControlBinop cBinop_wrZlon2x;
  ControlBinop cBinop_Svc98wcC;
  ControlBinop cBinop_wHBKH6tF;
  ControlBinop cBinop_hJc5HC6J;
  ControlBinop cBinop_HfXplvYv;
  ControlBinop cBinop_XVJAJIL5;
  ControlBinop cBinop_F2n9fSFf;
  ControlVar cVar_lXMhDqlF;
  ControlVar cVar_JxUv0ajF;
  ControlBinop cBinop_9EVHsDoy;
  ControlBinop cBinop_upAeqqDS;
  ControlBinop cBinop_VmqfhoC3;
  ControlBinop cBinop_SsnkV5tK;
  ControlBinop cBinop_7YilVYAE;
  ControlBinop cBinop_JCTuTc3Q;
  ControlBinop cBinop_s4dkSNC4;
  ControlBinop cBinop_zBg7y7H1;
  ControlBinop cBinop_L1mLfsFN;
  ControlBinop cBinop_JTn33Wnr;
  ControlBinop cBinop_iT92r4ue;
  ControlBinop cBinop_sc89MP4S;
  ControlBinop cBinop_Vn6arJJF;
  ControlBinop cBinop_PPogrYbJ;
  ControlBinop cBinop_NOCNJl1B;
  ControlBinop cBinop_7I8bMUyx;
  ControlBinop cBinop_1kDM4T0O;
  ControlBinop cBinop_4MahBPoq;
  ControlBinop cBinop_RFPZNCYK;
  ControlBinop cBinop_1C3dAk5X;
  ControlVar cVar_D5Dl0I6l;
  ControlVar cVar_Hh1tb3PN;
  ControlVar cVar_i9UrQRd1;
  ControlBinop cBinop_nagqLk6h;
  ControlBinop cBinop_Ow9jJSJn;
  ControlBinop cBinop_O13fy9f2;
  ControlBinop cBinop_I1icZ6cs;
  ControlBinop cBinop_DRUW7Sx0;
  ControlBinop cBinop_chauK1Ft;
  ControlBinop cBinop_uYblZtji;
  ControlBinop cBinop_na2CLQMK;
  ControlBinop cBinop_jqITEXB8;
  ControlBinop cBinop_6UZdg3nT;
  ControlBinop cBinop_qI9rWCOF;
  ControlBinop cBinop_XHg4rDrO;
  ControlBinop cBinop_WaAfeT2Z;
  ControlBinop cBinop_deGkjpTb;
  ControlBinop cBinop_ynCh7tSK;
  ControlBinop cBinop_JxB9x6Hi;
  ControlBinop cBinop_sgmO2Ohc;
  ControlBinop cBinop_Ln2wqx49;
  ControlBinop cBinop_2gvBywhU;
  ControlBinop cBinop_TEa7ex51;
  ControlBinop cBinop_9eciTNOU;
  ControlBinop cBinop_DN8TdhTI;
  ControlBinop cBinop_u5d9tByK;
  ControlVar cVar_aMgnu3yG;
  ControlVar cVar_DSHMvt3u;
  ControlVar cVar_ZmvDL3Ko;
  ControlBinop cBinop_jfWXp3Qe;
  ControlBinop cBinop_1QuXk2WN;
  ControlBinop cBinop_zFAFq9Lb;
  ControlBinop cBinop_K7TUvW9h;
  ControlBinop cBinop_WyOhiDV1;
  ControlBinop cBinop_VIst5pni;
  ControlBinop cBinop_KvbQ8Ldn;
  ControlBinop cBinop_H9kJRyie;
  ControlBinop cBinop_icHixfCO;
  ControlBinop cBinop_uJuKdr5g;
  ControlBinop cBinop_BpqDTW7p;
  ControlBinop cBinop_2cst7dhH;
  SignalVarf sVarf_VVnBcrur;
  SignalVarf sVarf_08Ze1Dn4;
  SignalVarf sVarf_6l7Ed3qZ;
  SignalVarf sVarf_gHTTdIFR;
  SignalVarf sVarf_qI5GHpx4;
  SignalVarf sVarf_IyULZQlq;
  SignalVarf sVarf_HYrtBFHo;
  SignalVarf sVarf_RvHkeihk;
  SignalVarf sVarf_B0E39dyv;
  ControlVar cVar_mm4wg3KK;
  ControlVar cVar_JV3PxlOg;
  ControlBinop cBinop_0K23buCf;
  ControlBinop cBinop_2gfhUPlb;
  ControlBinop cBinop_pLaqULkr;
  ControlBinop cBinop_3tHwTXK4;
  ControlBinop cBinop_qAsihnSu;
  ControlBinop cBinop_aD298d2I;
  ControlBinop cBinop_jJZcs8a5;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
