/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_pZ3WUhIk);
  numBytes += sLine_init(&sLine_mZznvB9g);
  numBytes += sLine_init(&sLine_bbtBN6d2);
  numBytes += sLine_init(&sLine_IEDzMTHs);
  numBytes += sLine_init(&sLine_IJW2SQCq);
  numBytes += sBiquad_init(&sBiquad_s_jV07Hw1U);
  numBytes += sLine_init(&sLine_IG1ZO7FY);
  numBytes += sLine_init(&sLine_o7AxAX61);
  numBytes += sLine_init(&sLine_gvcjVKkX);
  numBytes += sLine_init(&sLine_lr0UWOT6);
  numBytes += sBiquad_init(&sBiquad_s_OhzeUZxJ);
  numBytes += sLine_init(&sLine_3Oj3emeJ);
  numBytes += sLine_init(&sLine_XyD5jdhA);
  numBytes += sLine_init(&sLine_Cdl7DZwy);
  numBytes += sLine_init(&sLine_MB7I3zxQ);
  numBytes += sLine_init(&sLine_fBRRsgcS);
  numBytes += sBiquad_init(&sBiquad_s_awuFV6wN);
  numBytes += sLine_init(&sLine_RyQaImDd);
  numBytes += sLine_init(&sLine_gX9RJkcz);
  numBytes += sLine_init(&sLine_Q2MeyglR);
  numBytes += sLine_init(&sLine_2k42GY5k);
  numBytes += sLine_init(&sLine_sxnaJbui);
  numBytes += sBiquad_init(&sBiquad_s_bG9H9qF9);
  numBytes += sLine_init(&sLine_O0RVZWsg);
  numBytes += sLine_init(&sLine_6WhiIPzd);
  numBytes += sLine_init(&sLine_ic76AI5J);
  numBytes += sLine_init(&sLine_bpT4wfnQ);
  numBytes += sBiquad_init(&sBiquad_s_OoDIWNmd);
  numBytes += sLine_init(&sLine_RyvkNURZ);
  numBytes += sLine_init(&sLine_PG2X2Ujs);
  numBytes += sLine_init(&sLine_DCENHStM);
  numBytes += sLine_init(&sLine_RdcCFiRv);
  numBytes += sLine_init(&sLine_E5ZJNniV);
  numBytes += sBiquad_init(&sBiquad_s_LlW4Eixp);
  numBytes += cVar_init_f(&cVar_P8zTRe4S, 0.0f);
  numBytes += cVar_init_f(&cVar_xzovZCcn, 0.0f);
  numBytes += cVar_init_f(&cVar_25i8kIBw, 0.0f);
  numBytes += cVar_init_f(&cVar_XLivK4yo, 0.0f);
  numBytes += cSlice_init(&cSlice_bg7KeimG, 1, -1);
  numBytes += cVar_init_f(&cVar_3IVzgAfr, 1337.0f);
  numBytes += cVar_init_f(&cVar_AoMvPUFv, 0.0f);
  numBytes += cIf_init(&cIf_WUq27DVH, false);
  numBytes += cIf_init(&cIf_LVVBI795, false);
  numBytes += cBinop_init(&cBinop_5T8nsH61, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YENB3Lqq, false);
  numBytes += cBinop_init(&cBinop_WY3IyNhO, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ecLBW8ll, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wMAAHQI9, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ee1UGGEo, 0.0f);
  numBytes += cIf_init(&cIf_278BN7Qs, false);
  numBytes += cIf_init(&cIf_Hicr15c8, false);
  numBytes += cBinop_init(&cBinop_H0IEJEOd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eH6tGfhm, false);
  numBytes += cBinop_init(&cBinop_vtXs1l56, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7pi1A0j7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_86Rdjy3m, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1Hp9i8ZP, 0.0f);
  numBytes += cIf_init(&cIf_tOjcfWmO, false);
  numBytes += cIf_init(&cIf_OaUrrKmO, false);
  numBytes += cBinop_init(&cBinop_XklaBydk, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gU6XSia6, false);
  numBytes += cBinop_init(&cBinop_mDI3KZs7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4vM4cYhn, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nukKO33P, -15.0f); // __eq
  numBytes += cIf_init(&cIf_9fmTRZ3l, false);
  numBytes += cSlice_init(&cSlice_1g22djQg, 1, -1);
  numBytes += cVar_init_f(&cVar_B0BY5fhN, 0.0f);
  numBytes += cSlice_init(&cSlice_XKTZVxiv, 1, -1);
  numBytes += cVar_init_f(&cVar_oRMQpLQq, 0.0f);
  numBytes += cSlice_init(&cSlice_xg4RBRkb, 1, -1);
  numBytes += cVar_init_f(&cVar_pizACLpA, 0.0f);
  numBytes += cSlice_init(&cSlice_dkdh4cXv, 1, -1);
  numBytes += cVar_init_f(&cVar_hhW81AFE, 0.313f);
  numBytes += cBinop_init(&cBinop_8BwYaVDZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_9u1WfHpA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_sf69WUIs, 0.0f);
  numBytes += cVar_init_f(&cVar_eIFztZDJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_8NsgjAtm, 0.3f);
  numBytes += cBinop_init(&cBinop_PQO63okX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V07atBbP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r9rQ945Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qh0iv3R1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UBpwVAVq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_D1EnvUWR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CG1hurJ9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_r45CpgnP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YDt9KTwr, 0.0f);
  numBytes += cVar_init_f(&cVar_vDjpRPa0, 1337.0f);
  numBytes += cVar_init_f(&cVar_YgThZRk0, 0.313f);
  numBytes += cBinop_init(&cBinop_ZtfF0nUO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_llnX3u10, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L5DboYlb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DBulk4cA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cfUcTL8Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DdBPJbQz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_eD88OmAW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Mcf68jLk, 0.0f);
  numBytes += cVar_init_f(&cVar_r9bkVIHD, 1037.0f);
  numBytes += cVar_init_f(&cVar_BB8gRNno, 0.4f);
  numBytes += cBinop_init(&cBinop_UGOCgWrI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ThuFnS4z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hm4ibtqu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6VjxyOOM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k94Ejdp9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L8CsHnOf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_N2m7hpUP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RVIKx4O1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fgRza7gZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ebunRpLH, 1, -1);
  numBytes += cVar_init_f(&cVar_DrW5TBfa, 1337.0f);
  numBytes += cVar_init_f(&cVar_C1WLcOZB, 0.0f);
  numBytes += cIf_init(&cIf_l0zBc967, false);
  numBytes += cIf_init(&cIf_ey1MCEIM, false);
  numBytes += cBinop_init(&cBinop_NHSKOdld, 0.0f); // __pow
  numBytes += cIf_init(&cIf_NzXTDoLy, false);
  numBytes += cBinop_init(&cBinop_RZZEAjTM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bw6H6yhl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_mZNIhNdk, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_nFlHxJnt, 0.0f);
  numBytes += cIf_init(&cIf_3POxgcOt, false);
  numBytes += cIf_init(&cIf_2qhtC42y, false);
  numBytes += cBinop_init(&cBinop_1xQb9hf2, 0.0f); // __pow
  numBytes += cIf_init(&cIf_n8eYxXzR, false);
  numBytes += cBinop_init(&cBinop_VHwfS81u, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bbnfntFU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JYUhj5yX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_cx180ZdU, 0.0f);
  numBytes += cIf_init(&cIf_tZDr1aJw, false);
  numBytes += cIf_init(&cIf_ncIHttIa, false);
  numBytes += cBinop_init(&cBinop_EaoAnDq8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_K4UDzoCc, false);
  numBytes += cBinop_init(&cBinop_oNt8X88N, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_kvm3fW5O, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_oj8C8Fix, -15.0f); // __eq
  numBytes += cIf_init(&cIf_m32mDuPC, false);
  numBytes += cSlice_init(&cSlice_SpvcXiak, 1, -1);
  numBytes += cVar_init_f(&cVar_LEG1VUKd, 0.0f);
  numBytes += cSlice_init(&cSlice_8DlBSwsI, 1, -1);
  numBytes += cVar_init_f(&cVar_9HkK8sZj, 0.0f);
  numBytes += cSlice_init(&cSlice_sUuPJ6z3, 1, -1);
  numBytes += cVar_init_f(&cVar_5UiwPlYA, 0.0f);
  numBytes += cSlice_init(&cSlice_X3SXNpp3, 1, -1);
  numBytes += cVar_init_f(&cVar_KcaDshVq, 0.313f);
  numBytes += cBinop_init(&cBinop_YIPei5fi, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XB4MplxL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qg4viDZb, 0.0f);
  numBytes += cVar_init_f(&cVar_lXMhDqlF, 1337.0f);
  numBytes += cVar_init_f(&cVar_JxUv0ajF, 0.3f);
  numBytes += cBinop_init(&cBinop_upAeqqDS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7YilVYAE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JCTuTc3Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s4dkSNC4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zBg7y7H1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L1mLfsFN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iT92r4ue, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sc89MP4S, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_D5Dl0I6l, 0.0f);
  numBytes += cVar_init_f(&cVar_Hh1tb3PN, 1337.0f);
  numBytes += cVar_init_f(&cVar_i9UrQRd1, 0.313f);
  numBytes += cBinop_init(&cBinop_Ow9jJSJn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DRUW7Sx0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_chauK1Ft, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uYblZtji, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_na2CLQMK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6UZdg3nT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qI9rWCOF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aMgnu3yG, 0.0f);
  numBytes += cVar_init_f(&cVar_DSHMvt3u, 1037.0f);
  numBytes += cVar_init_f(&cVar_ZmvDL3Ko, 0.4f);
  numBytes += cBinop_init(&cBinop_1QuXk2WN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WyOhiDV1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VIst5pni, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KvbQ8Ldn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H9kJRyie, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_icHixfCO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VVnBcrur, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_08Ze1Dn4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6l7Ed3qZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gHTTdIFR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qI5GHpx4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IyULZQlq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HYrtBFHo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RvHkeihk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B0E39dyv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mm4wg3KK, 5705.6f);
  numBytes += cVar_init_f(&cVar_JV3PxlOg, 313.3f);
  numBytes += cBinop_init(&cBinop_0K23buCf, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_2gfhUPlb, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pLaqULkr, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KMsYOIpy_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sq9k2xqq_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ybba6zfs_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1eenD5T2_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yo0yF3ml_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_igvhVmWr_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1TEGd9G7_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YfygsoHv_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pq0fiBPT_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0KzfHi9S_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vPjwuvHs_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_soPsQjtS_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hdxZfauI_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SiERvPgG_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m5e7Aq39_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IJU3i5SG_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lquXcDOH_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yC8LpLLq_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5XRiVZMb_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bfy3t6Ua_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GhYqeCIc_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tUDVZbcG_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bKASk7QB_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_46iclud7_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3Gqoqpft_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sDNPnFrJ_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TP1M86va_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UGvLs6b1_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dhBjdEc4_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tCatBsZH_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e14VlplK_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bVBKrPX1_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bhSlk7fs_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_P8zTRe4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wqHgOIYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xzovZCcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7G75aA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_25i8kIBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_trJ6z90N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_XLivK4yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dzzEwIvZ_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jsDfF9db_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AnAVIFMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bSlPDTYK_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_sOOVOska_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bg7KeimG, 0, m, &cSlice_bg7KeimG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hL2jmX6G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_bg7KeimG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rBX77V0p_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rBX77V0p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_3IVzgAfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rBX77V0p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_rBX77V0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1TEGd9G7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_AoMvPUFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nOwtZ4FP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WUq27DVH, 0, m, &cIf_WUq27DVH_sendMessage);
}

void Heavy_WSTD_EQ::cIf_WUq27DVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QeKQDlTe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_LVVBI795_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_IRDsPsdn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_sbrQtDYp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_JTGHXoNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5T8nsH61, HV_BINOP_POW, 0, m, &cBinop_5T8nsH61_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5T8nsH61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YENB3Lqq, 0, m, &cIf_YENB3Lqq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9DQfITy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nzQbAj7D_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JCZ1qrfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LVVBI795, 0, m, &cIf_LVVBI795_sendMessage);
}

void Heavy_WSTD_EQ::cCast_G2gKBOUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ze6dmtjS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ze6dmtjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LVVBI795, 1, m, &cIf_LVVBI795_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sbrQtDYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9DQfITy5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_IRDsPsdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YENB3Lqq, 0, m, &cIf_YENB3Lqq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nzQbAj7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5T8nsH61, HV_BINOP_POW, 1, m, &cBinop_5T8nsH61_sendMessage);
  cMsg_JTGHXoNQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_YENB3Lqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_N2m7hpUP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_nOwtZ4FP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WUq27DVH, 1, m, &cIf_WUq27DVH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QeKQDlTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ecLBW8ll, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ecLBW8ll_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMAAHQI9, HV_BINOP_EQ, 1, m, &cBinop_wMAAHQI9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8ZAJbDDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WY3IyNhO, HV_BINOP_ADD, 0, m, &cBinop_WY3IyNhO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WY3IyNhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2gKBOUv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JCZ1qrfg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ecLBW8ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YENB3Lqq, 1, m, &cIf_YENB3Lqq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wMAAHQI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ff2NIt6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ff2NIt6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_N2m7hpUP, m);
}

void Heavy_WSTD_EQ::cCast_2optDNnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AoMvPUFv, 0, m, &cVar_AoMvPUFv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JPg1lWXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ZAJbDDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_g1XHO7aT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WY3IyNhO, HV_BINOP_ADD, 1, m, &cBinop_WY3IyNhO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ecLBW8ll, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ecLBW8ll_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMAAHQI9, HV_BINOP_EQ, 0, m, &cBinop_wMAAHQI9_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ee1UGGEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wGRfGUn3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_278BN7Qs, 0, m, &cIf_278BN7Qs_sendMessage);
}

void Heavy_WSTD_EQ::cIf_278BN7Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XhAKVKdw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_Hicr15c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_sYd4NC98_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_fjhLvaZp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_YmBzeRGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H0IEJEOd, HV_BINOP_POW, 0, m, &cBinop_H0IEJEOd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H0IEJEOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eH6tGfhm, 0, m, &cIf_eH6tGfhm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gJfMD610_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Lbmc1JBT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vb3BAKrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_18Hh7k2f_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gTUXWPK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hicr15c8, 0, m, &cIf_Hicr15c8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_18Hh7k2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hicr15c8, 1, m, &cIf_Hicr15c8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fjhLvaZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gJfMD610_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sYd4NC98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eH6tGfhm, 0, m, &cIf_eH6tGfhm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Lbmc1JBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H0IEJEOd, HV_BINOP_POW, 1, m, &cBinop_H0IEJEOd_sendMessage);
  cMsg_YmBzeRGG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_eH6tGfhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ayhbgctg_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TeDrjgKe_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_669r4OWl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_wGRfGUn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_278BN7Qs, 1, m, &cIf_278BN7Qs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XhAKVKdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pi1A0j7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7pi1A0j7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_86Rdjy3m, HV_BINOP_EQ, 1, m, &cBinop_86Rdjy3m_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kWqjnxY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtXs1l56, HV_BINOP_ADD, 0, m, &cBinop_vtXs1l56_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vtXs1l56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vb3BAKrA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gTUXWPK4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7pi1A0j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eH6tGfhm, 1, m, &cIf_eH6tGfhm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_86Rdjy3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nB7lT71d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nB7lT71d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ayhbgctg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TeDrjgKe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_669r4OWl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zyxKkxLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtXs1l56, HV_BINOP_ADD, 1, m, &cBinop_vtXs1l56_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pi1A0j7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7pi1A0j7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_86Rdjy3m, HV_BINOP_EQ, 0, m, &cBinop_86Rdjy3m_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Lku0hxk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ee1UGGEo, 0, m, &cVar_ee1UGGEo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zsCK6Wqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kWqjnxY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_1Hp9i8ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pz0o5ClA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tOjcfWmO, 0, m, &cIf_tOjcfWmO_sendMessage);
}

void Heavy_WSTD_EQ::cIf_tOjcfWmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Bl7roO6W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_OaUrrKmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oA9Z8pPu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_DCewnYWq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_bqqf0bBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XklaBydk, HV_BINOP_POW, 0, m, &cBinop_XklaBydk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XklaBydk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gU6XSia6, 0, m, &cIf_gU6XSia6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3XZcgjKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_h6wQwgiR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9Zijm57C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OaUrrKmO, 0, m, &cIf_OaUrrKmO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OIAZjjzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TACHvyvW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TACHvyvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OaUrrKmO, 1, m, &cIf_OaUrrKmO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DCewnYWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3XZcgjKX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_oA9Z8pPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gU6XSia6, 0, m, &cIf_gU6XSia6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h6wQwgiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XklaBydk, HV_BINOP_POW, 1, m, &cBinop_XklaBydk_sendMessage);
  cMsg_bqqf0bBe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_gU6XSia6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_fgRza7gZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_pz0o5ClA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tOjcfWmO, 1, m, &cIf_tOjcfWmO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Bl7roO6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4vM4cYhn, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4vM4cYhn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nukKO33P, HV_BINOP_EQ, 1, m, &cBinop_nukKO33P_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_umKO7Viq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mDI3KZs7, HV_BINOP_ADD, 0, m, &cBinop_mDI3KZs7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mDI3KZs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OIAZjjzg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Zijm57C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4vM4cYhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gU6XSia6, 1, m, &cIf_gU6XSia6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nukKO33P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RD5SMJMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_RD5SMJMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fgRza7gZ, m);
}

void Heavy_WSTD_EQ::cCast_PoF6lTnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_umKO7Viq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_sSQ7NV4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mDI3KZs7, HV_BINOP_ADD, 1, m, &cBinop_mDI3KZs7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4vM4cYhn, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4vM4cYhn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nukKO33P, HV_BINOP_EQ, 0, m, &cBinop_nukKO33P_sendMessage);
}

void Heavy_WSTD_EQ::cCast_axRGJZTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1Hp9i8ZP, 0, m, &cVar_1Hp9i8ZP_sendMessage);
}

void Heavy_WSTD_EQ::cIf_9fmTRZ3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_RVIKx4O1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_GAdbXhTd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1g22djQg, 0, m, &cSlice_1g22djQg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6sxe0bmm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_1g22djQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G85gBKzD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G85gBKzD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_B0BY5fhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G85gBKzD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_G85gBKzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yo0yF3ml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_6sxe0bmm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XKTZVxiv, 0, m, &cSlice_XKTZVxiv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sOOVOska_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_XKTZVxiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5UoVXFCs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5UoVXFCs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_oRMQpLQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5UoVXFCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_5UoVXFCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pq0fiBPT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_hL2jmX6G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xg4RBRkb, 0, m, &cSlice_xg4RBRkb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CLKNqvh9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xg4RBRkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PqmvClIC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PqmvClIC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_pizACLpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PqmvClIC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PqmvClIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_igvhVmWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_CLKNqvh9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dkdh4cXv, 0, m, &cSlice_dkdh4cXv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_dkdh4cXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O3lorrZL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O3lorrZL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_hhW81AFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O3lorrZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_O3lorrZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YfygsoHv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_XFMAWiiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pZ3WUhIk, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_um9Xamgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mZznvB9g, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AFuyhemB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bbtBN6d2, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wCLaKOVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IEDzMTHs, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JBHvVFcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IJW2SQCq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_76KexZyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YDT4BfAx_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_YDT4BfAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8BwYaVDZ, HV_BINOP_DIVIDE, 1, m, &cBinop_8BwYaVDZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dITDqUl5_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jv68lwrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_c7gHghBK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SInA4tL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jv68lwrc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c7gHghBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8BwYaVDZ, HV_BINOP_DIVIDE, 0, m, &cBinop_8BwYaVDZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dITDqUl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SInA4tL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8BwYaVDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9u1WfHpA, HV_BINOP_MULTIPLY, 1, m, &cBinop_9u1WfHpA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9u1WfHpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F6CIIuZy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tZBxgdvh_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_8iydtzk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ypdx8PSM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SHuFEi3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4Ep4yxZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fZlH070t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QVmGugpe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QVmGugpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9u1WfHpA, HV_BINOP_MULTIPLY, 0, m, &cBinop_9u1WfHpA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cXqkAbRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_W2zAh4q2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W2zAh4q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TNKOT6kw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tWq6NAMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sf69WUIs, 1, m, &cVar_sf69WUIs_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sf69WUIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H0LInKQD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kgK2ECvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V07atBbP, HV_BINOP_MULTIPLY, 1, m, &cBinop_V07atBbP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HRdxhAnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kgK2ECvo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QHEWK9R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J6WUoz81_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_J6WUoz81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r9rQ945Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_r9rQ945Y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TmfDHBep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh0iv3R1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qh0iv3R1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GgVM9jLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TmfDHBep_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_phTHHpTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UBpwVAVq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UBpwVAVq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CNWmONzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NR5zPqc8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NR5zPqc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D1EnvUWR, HV_BINOP_MULTIPLY, 1, m, &cBinop_D1EnvUWR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_eIFztZDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V3puWmdG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fZlH070t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oEtbb1dS_sendMessage);
}

void Heavy_WSTD_EQ::cVar_8NsgjAtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_cXqkAbRg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tZBxgdvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SHuFEi3F_sendMessage);
}

void Heavy_WSTD_EQ::cCast_F6CIIuZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8iydtzk0_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ypdx8PSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_soPsQjtS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_4Ep4yxZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vPjwuvHs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VMMmu8om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0KzfHi9S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_TNKOT6kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iq1r0Lzd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iq1r0Lzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQO63okX, HV_BINOP_MULTIPLY, 1, m, &cBinop_PQO63okX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PQO63okX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ifycBbvZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ifycBbvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VMMmu8om_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_H0LInKQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7rw4olyO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7rw4olyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgoYLMeX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zXVkxZfB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dMiSQShB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R11MjMCr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6803bli2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hnDuo9eV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V07atBbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XFMAWiiN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r9rQ945Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_um9Xamgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Qh0iv3R1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AFuyhemB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UBpwVAVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wCLaKOVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_D1EnvUWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JBHvVFcS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_BjGn5tZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8NsgjAtm, 1, m, &cVar_8NsgjAtm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cgvOONpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eIFztZDJ, 0, m, &cVar_eIFztZDJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_R11MjMCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh0iv3R1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qh0iv3R1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MgoYLMeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_hnDuo9eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V07atBbP, HV_BINOP_MULTIPLY, 0, m, &cBinop_V07atBbP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dMiSQShB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UBpwVAVq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UBpwVAVq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6803bli2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r9rQ945Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_r9rQ945Y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zXVkxZfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D1EnvUWR, HV_BINOP_MULTIPLY, 0, m, &cBinop_D1EnvUWR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oEtbb1dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sf69WUIs, 0, m, &cVar_sf69WUIs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V3puWmdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8NsgjAtm, 0, m, &cVar_8NsgjAtm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WQlx3D9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IG1ZO7FY, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_id9xoq0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o7AxAX61, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cpyai6Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gvcjVKkX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jslq7dAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lr0UWOT6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FYamITiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BsnyaRwM_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_BsnyaRwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CG1hurJ9, HV_BINOP_DIVIDE, 1, m, &cBinop_CG1hurJ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s1rESxhq_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FiHxCW0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OsQ9uYZS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_pdfHoSND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FiHxCW0g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OsQ9uYZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CG1hurJ9, HV_BINOP_DIVIDE, 0, m, &cBinop_CG1hurJ9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_s1rESxhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pdfHoSND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CG1hurJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r45CpgnP, HV_BINOP_MULTIPLY, 1, m, &cBinop_r45CpgnP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_r45CpgnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xhbNaB0h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5qiOEgMN_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_7wVJgY8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CNDmt0j6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_UAzYjNji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ww5Pn33j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AmnuL4ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5t5cIYaM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5t5cIYaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r45CpgnP, HV_BINOP_MULTIPLY, 0, m, &cBinop_r45CpgnP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EEiCaxOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_72anlsDw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_72anlsDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y6eShswu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oxcWVamM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L5DboYlb, HV_BINOP_MULTIPLY, 1, m, &cBinop_L5DboYlb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pHcSUrPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YDt9KTwr, 1, m, &cVar_YDt9KTwr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FBGEm8RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBulk4cA, HV_BINOP_MULTIPLY, 1, m, &cBinop_DBulk4cA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JEkpUsvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_61sucHJg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_61sucHJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cfUcTL8Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_cfUcTL8Q_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YDt9KTwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PnkdZFl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_vDjpRPa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RmlLcgGX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_AmnuL4ks_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLb326Tz_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YgThZRk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EEiCaxOC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xhbNaB0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7wVJgY8N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5qiOEgMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UAzYjNji_sendMessage);
}

void Heavy_WSTD_EQ::cSend_CNDmt0j6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m5e7Aq39_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Ww5Pn33j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SiERvPgG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Cb3pLE5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hdxZfauI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Y6eShswu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MFlKlKfW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MFlKlKfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZtfF0nUO, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZtfF0nUO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZtfF0nUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ewxE3NTq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ewxE3NTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Cb3pLE5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PnkdZFl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2RYu2yN8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2RYu2yN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OVhoY027_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EdgGyPvG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i1fHB6fA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MZmn6FCn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_llnX3u10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WQlx3D9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_L5DboYlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_id9xoq0E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DBulk4cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cpyai6Ln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cfUcTL8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jslq7dAh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_P4p5lmps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vDjpRPa0, 0, m, &cVar_vDjpRPa0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ccQqrDjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YgThZRk0, 1, m, &cVar_YgThZRk0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RLb326Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YDt9KTwr, 0, m, &cVar_YDt9KTwr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RmlLcgGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YgThZRk0, 0, m, &cVar_YgThZRk0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OVhoY027_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cfUcTL8Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_cfUcTL8Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i1fHB6fA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L5DboYlb, HV_BINOP_MULTIPLY, 0, m, &cBinop_L5DboYlb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EdgGyPvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBulk4cA, HV_BINOP_MULTIPLY, 0, m, &cBinop_DBulk4cA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MZmn6FCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llnX3u10, HV_BINOP_MULTIPLY, 0, m, &cBinop_llnX3u10_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zK38LQjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3Oj3emeJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BCyA2bOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XyD5jdhA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ptf0UZRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cdl7DZwy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jlevrQ9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MB7I3zxQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Tl665EEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fBRRsgcS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eD4di4nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lQ7fYHwU_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_lQ7fYHwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DdBPJbQz, HV_BINOP_DIVIDE, 1, m, &cBinop_DdBPJbQz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jIPwlYK9_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_UJiuFzMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Qh3jCn5R_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_UOVsNwHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_UJiuFzMK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qh3jCn5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DdBPJbQz, HV_BINOP_DIVIDE, 0, m, &cBinop_DdBPJbQz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jIPwlYK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UOVsNwHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DdBPJbQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eD88OmAW, HV_BINOP_MULTIPLY, 1, m, &cBinop_eD88OmAW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eD88OmAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yXc7ddyw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cQqgcdEa_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_RlbeS80Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_82SZ2HlG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_0hqbOhwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_70z6sj0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nbXWqdzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_kMOX5vpr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kMOX5vpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eD88OmAW, HV_BINOP_MULTIPLY, 0, m, &cBinop_eD88OmAW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sH6asdzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Mqf1Lhza_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Mqf1Lhza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_89C3ewk7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FlU1j6yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThuFnS4z, HV_BINOP_MULTIPLY, 1, m, &cBinop_ThuFnS4z_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8zYlXTY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jhoZ8MFP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jhoZ8MFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FlU1j6yw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ac47BNNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4VO2cI2n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4VO2cI2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hm4ibtqu, HV_BINOP_MULTIPLY, 1, m, &cBinop_hm4ibtqu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CjhEIO1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6VjxyOOM, HV_BINOP_MULTIPLY, 1, m, &cBinop_6VjxyOOM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_i3kI5xWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V5WzNOpM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V5WzNOpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CjhEIO1Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7UAgDHu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mcf68jLk, 1, m, &cVar_Mcf68jLk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UfCK1V8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k94Ejdp9, HV_BINOP_MULTIPLY, 1, m, &cBinop_k94Ejdp9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_G4kVtFQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E7volRfl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_E7volRfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L8CsHnOf, HV_BINOP_MULTIPLY, 1, m, &cBinop_L8CsHnOf_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Mcf68jLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rkh0TZm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_r9bkVIHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TLVfFbcQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nbXWqdzW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5aESdSb7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_BB8gRNno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sH6asdzP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yXc7ddyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RlbeS80Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cQqgcdEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0hqbOhwa_sendMessage);
}

void Heavy_WSTD_EQ::cSend_82SZ2HlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yC8LpLLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_70z6sj0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lquXcDOH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Q6sHDo7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IJU3i5SG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_89C3ewk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_seQiQH35_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_seQiQH35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGOCgWrI, HV_BINOP_MULTIPLY, 1, m, &cBinop_UGOCgWrI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UGOCgWrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_i6YvsMv0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i6YvsMv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q6sHDo7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_rkh0TZm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XUua2WXk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XUua2WXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4K1X6l1I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TCdrfYYz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AJHkaaep_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LDsv3FGH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZhXskjXR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HArYPPKH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ThuFnS4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zK38LQjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hm4ibtqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCyA2bOq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6VjxyOOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ptf0UZRw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_k94Ejdp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jlevrQ9O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_L8CsHnOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tl665EEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Z8DfvBmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r9bkVIHD, 0, m, &cVar_r9bkVIHD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P57YKtbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BB8gRNno, 1, m, &cVar_BB8gRNno_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HArYPPKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThuFnS4z, HV_BINOP_MULTIPLY, 0, m, &cBinop_ThuFnS4z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AJHkaaep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k94Ejdp9, HV_BINOP_MULTIPLY, 0, m, &cBinop_k94Ejdp9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZhXskjXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hm4ibtqu, HV_BINOP_MULTIPLY, 0, m, &cBinop_hm4ibtqu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TCdrfYYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L8CsHnOf, HV_BINOP_MULTIPLY, 0, m, &cBinop_L8CsHnOf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LDsv3FGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6VjxyOOM, HV_BINOP_MULTIPLY, 0, m, &cBinop_6VjxyOOM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4K1X6l1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_TLVfFbcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BB8gRNno, 0, m, &cVar_BB8gRNno_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5aESdSb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mcf68jLk, 0, m, &cVar_Mcf68jLk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ayhbgctg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9fmTRZ3l, 1, m, &cIf_9fmTRZ3l_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aMFiiiXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RVIKx4O1, m);
}

void Heavy_WSTD_EQ::cBinop_TeDrjgKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aMFiiiXX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_669r4OWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9fmTRZ3l, 0, m, &cIf_9fmTRZ3l_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_ZQJbC4DK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ebunRpLH, 0, m, &cSlice_ebunRpLH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZXjqYSYH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ebunRpLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VDJtjn46_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VDJtjn46_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_DrW5TBfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VDJtjn46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VDJtjn46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GhYqeCIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_C1WLcOZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tTtnIrwo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_l0zBc967, 0, m, &cIf_l0zBc967_sendMessage);
}

void Heavy_WSTD_EQ::cIf_l0zBc967_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yl8JZjAm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_ey1MCEIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VN0vbidI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_a7lSlc0g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_kQaxngxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NHSKOdld, HV_BINOP_POW, 0, m, &cBinop_NHSKOdld_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NHSKOdld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NzXTDoLy, 0, m, &cIf_NzXTDoLy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LfF0O1Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Yyr4DeJn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QeYsU9Ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ey1MCEIM, 0, m, &cIf_ey1MCEIM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GK42kAkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SbrbVyo7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SbrbVyo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ey1MCEIM, 1, m, &cIf_ey1MCEIM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a7lSlc0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_LfF0O1Qa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VN0vbidI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_NzXTDoLy, 0, m, &cIf_NzXTDoLy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yyr4DeJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NHSKOdld, HV_BINOP_POW, 1, m, &cBinop_NHSKOdld_sendMessage);
  cMsg_kQaxngxC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_NzXTDoLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VVnBcrur, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_tTtnIrwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l0zBc967, 1, m, &cIf_l0zBc967_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yl8JZjAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bw6H6yhl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bw6H6yhl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZNIhNdk, HV_BINOP_EQ, 1, m, &cBinop_mZNIhNdk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iqv7Tl5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RZZEAjTM, HV_BINOP_ADD, 0, m, &cBinop_RZZEAjTM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RZZEAjTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GK42kAkA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QeYsU9Ep_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bw6H6yhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NzXTDoLy, 1, m, &cIf_NzXTDoLy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mZNIhNdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V7QN9INA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V7QN9INA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VVnBcrur, m);
}

void Heavy_WSTD_EQ::cCast_auq8VMWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iqv7Tl5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_JPq5abLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RZZEAjTM, HV_BINOP_ADD, 1, m, &cBinop_RZZEAjTM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bw6H6yhl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bw6H6yhl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZNIhNdk, HV_BINOP_EQ, 0, m, &cBinop_mZNIhNdk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ASqvjHWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C1WLcOZB, 0, m, &cVar_C1WLcOZB_sendMessage);
}

void Heavy_WSTD_EQ::cVar_nFlHxJnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kEBF1zc0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3POxgcOt, 0, m, &cIf_3POxgcOt_sendMessage);
}

void Heavy_WSTD_EQ::cIf_3POxgcOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hv8lrj9s_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_2qhtC42y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xUyRS4vu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MBDUWa1n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_mZbqoRxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1xQb9hf2, HV_BINOP_POW, 0, m, &cBinop_1xQb9hf2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1xQb9hf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n8eYxXzR, 0, m, &cIf_n8eYxXzR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ul624QST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_siEh51Uw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Oq2tr7Bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R08zAZVO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5nTHiObn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2qhtC42y, 0, m, &cIf_2qhtC42y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R08zAZVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2qhtC42y, 1, m, &cIf_2qhtC42y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MBDUWa1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ul624QST_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_xUyRS4vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n8eYxXzR, 0, m, &cIf_n8eYxXzR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_siEh51Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1xQb9hf2, HV_BINOP_POW, 1, m, &cBinop_1xQb9hf2_sendMessage);
  cMsg_mZbqoRxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_n8eYxXzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uJuKdr5g_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BpqDTW7p_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_2cst7dhH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_kEBF1zc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3POxgcOt, 1, m, &cIf_3POxgcOt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hv8lrj9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbnfntFU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bbnfntFU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JYUhj5yX, HV_BINOP_EQ, 1, m, &cBinop_JYUhj5yX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Z5a0onEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VHwfS81u, HV_BINOP_ADD, 0, m, &cBinop_VHwfS81u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VHwfS81u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oq2tr7Bs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5nTHiObn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bbnfntFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n8eYxXzR, 1, m, &cIf_n8eYxXzR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JYUhj5yX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LOClTyOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_LOClTyOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uJuKdr5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BpqDTW7p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_2cst7dhH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eG9Lp893_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nFlHxJnt, 0, m, &cVar_nFlHxJnt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sYCihrcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z5a0onEv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_dDhPTzbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VHwfS81u, HV_BINOP_ADD, 1, m, &cBinop_VHwfS81u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbnfntFU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bbnfntFU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JYUhj5yX, HV_BINOP_EQ, 0, m, &cBinop_JYUhj5yX_sendMessage);
}

void Heavy_WSTD_EQ::cVar_cx180ZdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9xW3FdWl_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tZDr1aJw, 0, m, &cIf_tZDr1aJw_sendMessage);
}

void Heavy_WSTD_EQ::cIf_tZDr1aJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LMVc1CoL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_ncIHttIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_NzOTMP1K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_6yJcUHAS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_CCmKyT8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EaoAnDq8, HV_BINOP_POW, 0, m, &cBinop_EaoAnDq8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EaoAnDq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4UDzoCc, 0, m, &cIf_K4UDzoCc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WKq5n8Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_HYZssjCv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oJupXJNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ncIHttIa, 0, m, &cIf_ncIHttIa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6iKWSRhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VGnZJMp4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VGnZJMp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ncIHttIa, 1, m, &cIf_ncIHttIa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6yJcUHAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WKq5n8Tj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_NzOTMP1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_K4UDzoCc, 0, m, &cIf_K4UDzoCc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HYZssjCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EaoAnDq8, HV_BINOP_POW, 1, m, &cBinop_EaoAnDq8_sendMessage);
  cMsg_CCmKyT8e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_K4UDzoCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6l7Ed3qZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_9xW3FdWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tZDr1aJw, 1, m, &cIf_tZDr1aJw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LMVc1CoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvm3fW5O, HV_BINOP_GREATER_THAN, 1, m, &cBinop_kvm3fW5O_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oj8C8Fix, HV_BINOP_EQ, 1, m, &cBinop_oj8C8Fix_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aj9xGKDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNt8X88N, HV_BINOP_ADD, 0, m, &cBinop_oNt8X88N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oNt8X88N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6iKWSRhi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oJupXJNf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kvm3fW5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4UDzoCc, 1, m, &cIf_K4UDzoCc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oj8C8Fix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DWQ9ozcC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_DWQ9ozcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6l7Ed3qZ, m);
}

void Heavy_WSTD_EQ::cCast_zo2Qz3qO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cx180ZdU, 0, m, &cVar_cx180ZdU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4JYQuTbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aj9xGKDm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_pUXEmVPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNt8X88N, HV_BINOP_ADD, 1, m, &cBinop_oNt8X88N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvm3fW5O, HV_BINOP_GREATER_THAN, 0, m, &cBinop_kvm3fW5O_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oj8C8Fix, HV_BINOP_EQ, 0, m, &cBinop_oj8C8Fix_sendMessage);
}

void Heavy_WSTD_EQ::cIf_m32mDuPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_08Ze1Dn4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_Uq0XcwsW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SpvcXiak, 0, m, &cSlice_SpvcXiak_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DV0CAYLG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_SpvcXiak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mkbTDN29_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mkbTDN29_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_LEG1VUKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mkbTDN29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mkbTDN29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5XRiVZMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_DV0CAYLG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8DlBSwsI, 0, m, &cSlice_8DlBSwsI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZQJbC4DK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_8DlBSwsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IubI0hkk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IubI0hkk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_9HkK8sZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IubI0hkk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_IubI0hkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bKASk7QB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ZXjqYSYH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sUuPJ6z3, 0, m, &cSlice_sUuPJ6z3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1CJcSTnA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sUuPJ6z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Wz4U0Sqg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Wz4U0Sqg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_5UiwPlYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Wz4U0Sqg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Wz4U0Sqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bfy3t6Ua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_1CJcSTnA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X3SXNpp3, 0, m, &cSlice_X3SXNpp3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_X3SXNpp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mjrNXrnD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mjrNXrnD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_KcaDshVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mjrNXrnD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mjrNXrnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tUDVZbcG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9i3wu2ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RyQaImDd, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_o79cE5Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gX9RJkcz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ovn0u0Ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q2MeyglR, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_H7Vh6IaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2k42GY5k, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WAW2npGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sxnaJbui, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_faUdqUa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jJkzBnDf_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_jJkzBnDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIPei5fi, HV_BINOP_DIVIDE, 1, m, &cBinop_YIPei5fi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lICRDpy_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_snc6lkS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_a6mk20YJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZAb09Txm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_snc6lkS3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a6mk20YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIPei5fi, HV_BINOP_DIVIDE, 0, m, &cBinop_YIPei5fi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3lICRDpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZAb09Txm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YIPei5fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XB4MplxL, HV_BINOP_MULTIPLY, 1, m, &cBinop_XB4MplxL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XB4MplxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E4z4Zf8K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OW8R9DPF_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Y7WswxsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BwnD14p1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_jUiTk0FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3h3Wi7Ir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HLea3FWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zyGDTFgE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zyGDTFgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XB4MplxL, HV_BINOP_MULTIPLY, 0, m, &cBinop_XB4MplxL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RnhefgQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aHZIRudM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aHZIRudM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HWNxFQq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jDmT6WAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qg4viDZb, 1, m, &cVar_qg4viDZb_sendMessage);
}

void Heavy_WSTD_EQ::cVar_qg4viDZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_slRyKm85_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_RFkfGR0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YilVYAE, HV_BINOP_MULTIPLY, 1, m, &cBinop_7YilVYAE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wrZlon2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RFkfGR0y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Svc98wcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wHBKH6tF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wHBKH6tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCTuTc3Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_JCTuTc3Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hJc5HC6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4dkSNC4, HV_BINOP_MULTIPLY, 1, m, &cBinop_s4dkSNC4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HfXplvYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hJc5HC6J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XVJAJIL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBg7y7H1, HV_BINOP_MULTIPLY, 1, m, &cBinop_zBg7y7H1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Q1LJzXVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F2n9fSFf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F2n9fSFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1mLfsFN, HV_BINOP_MULTIPLY, 1, m, &cBinop_L1mLfsFN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lXMhDqlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sunYj1VG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HLea3FWs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bVxXHjCq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_JxUv0ajF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RnhefgQA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OW8R9DPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jUiTk0FO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E4z4Zf8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Y7WswxsD_sendMessage);
}

void Heavy_WSTD_EQ::cSend_BwnD14p1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sDNPnFrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3h3Wi7Ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3Gqoqpft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_8ejGYNhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_46iclud7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_HWNxFQq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9EVHsDoy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9EVHsDoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upAeqqDS, HV_BINOP_MULTIPLY, 1, m, &cBinop_upAeqqDS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_upAeqqDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VmqfhoC3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VmqfhoC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8ejGYNhf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_slRyKm85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SsnkV5tK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SsnkV5tK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Xy5wG2z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u0OBiy9D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZHpnWlLl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rJyqAfAK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ruUv1jij_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wfnud3FK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7YilVYAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9i3wu2ev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JCTuTc3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o79cE5Si_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_s4dkSNC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ovn0u0Ev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zBg7y7H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H7Vh6IaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_L1mLfsFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WAW2npGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_BXeD8Eep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JxUv0ajF, 1, m, &cVar_JxUv0ajF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EFPqL7iG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lXMhDqlF, 0, m, &cVar_lXMhDqlF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ruUv1jij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCTuTc3Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_JCTuTc3Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u0OBiy9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1mLfsFN, HV_BINOP_MULTIPLY, 0, m, &cBinop_L1mLfsFN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rJyqAfAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4dkSNC4, HV_BINOP_MULTIPLY, 0, m, &cBinop_s4dkSNC4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0Xy5wG2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_Wfnud3FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YilVYAE, HV_BINOP_MULTIPLY, 0, m, &cBinop_7YilVYAE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZHpnWlLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBg7y7H1, HV_BINOP_MULTIPLY, 0, m, &cBinop_zBg7y7H1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bVxXHjCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qg4viDZb, 0, m, &cVar_qg4viDZb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sunYj1VG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JxUv0ajF, 0, m, &cVar_JxUv0ajF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_xD2aJdfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O0RVZWsg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EGWD1Jjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6WhiIPzd, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hdaWKwxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ic76AI5J, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Vlc8yLN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bpT4wfnQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_t8pU3qyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UJdlgL0H_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_UJdlgL0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iT92r4ue, HV_BINOP_DIVIDE, 1, m, &cBinop_iT92r4ue_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x6ulymCM_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YmgOmhnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JTn33Wnr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OuhkAJhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_YmgOmhnW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JTn33Wnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iT92r4ue, HV_BINOP_DIVIDE, 0, m, &cBinop_iT92r4ue_sendMessage);
}

void Heavy_WSTD_EQ::cCast_x6ulymCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OuhkAJhn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iT92r4ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sc89MP4S, HV_BINOP_MULTIPLY, 1, m, &cBinop_sc89MP4S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sc89MP4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_olLJnsDW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6mo5L3e1_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_0USEKXuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sy66keeO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_nGEqWfCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aRgbc8d5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Vn6arJJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PPogrYbJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PPogrYbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sc89MP4S, HV_BINOP_MULTIPLY, 0, m, &cBinop_sc89MP4S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NOCNJl1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_7I8bMUyx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7I8bMUyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fxRIoFXg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1kDM4T0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_chauK1Ft, HV_BINOP_MULTIPLY, 1, m, &cBinop_chauK1Ft_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4MahBPoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5Dl0I6l, 1, m, &cVar_D5Dl0I6l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RFPZNCYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYblZtji, HV_BINOP_MULTIPLY, 1, m, &cBinop_uYblZtji_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Sych993x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1C3dAk5X_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1C3dAk5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_na2CLQMK, HV_BINOP_MULTIPLY, 1, m, &cBinop_na2CLQMK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_D5Dl0I6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtyWJAE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Hh1tb3PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_czjWhRxP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Vn6arJJF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cg2LFYrv_sendMessage);
}

void Heavy_WSTD_EQ::cVar_i9UrQRd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NOCNJl1B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6mo5L3e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nGEqWfCJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_olLJnsDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0USEKXuU_sendMessage);
}

void Heavy_WSTD_EQ::cSend_sy66keeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dhBjdEc4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_aRgbc8d5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UGvLs6b1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_89JzqK2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TP1M86va_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fxRIoFXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nagqLk6h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nagqLk6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ow9jJSJn, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ow9jJSJn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ow9jJSJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_O13fy9f2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O13fy9f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_89JzqK2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_BtyWJAE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_I1icZ6cs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I1icZ6cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TolvadCC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0uYYsULa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ucHwe5VZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nQzqOAZb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DRUW7Sx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xD2aJdfk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_chauK1Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EGWD1Jjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uYblZtji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hdaWKwxi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_na2CLQMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vlc8yLN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_IlfFVuSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hh1tb3PN, 0, m, &cVar_Hh1tb3PN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8FZZv6Fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i9UrQRd1, 1, m, &cVar_i9UrQRd1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Cg2LFYrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5Dl0I6l, 0, m, &cVar_D5Dl0I6l_sendMessage);
}

void Heavy_WSTD_EQ::cCast_czjWhRxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i9UrQRd1, 0, m, &cVar_i9UrQRd1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TolvadCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_na2CLQMK, HV_BINOP_MULTIPLY, 0, m, &cBinop_na2CLQMK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ucHwe5VZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_chauK1Ft, HV_BINOP_MULTIPLY, 0, m, &cBinop_chauK1Ft_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0uYYsULa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYblZtji, HV_BINOP_MULTIPLY, 0, m, &cBinop_uYblZtji_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nQzqOAZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRUW7Sx0, HV_BINOP_MULTIPLY, 0, m, &cBinop_DRUW7Sx0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BtwxzOxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RyvkNURZ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XjCu0VJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PG2X2Ujs, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7ZCPRHYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DCENHStM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UaZsGr0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RdcCFiRv, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pgz7n11D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E5ZJNniV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EJkEM8bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fIwMo9jV_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_fIwMo9jV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6UZdg3nT, HV_BINOP_DIVIDE, 1, m, &cBinop_6UZdg3nT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IieKGfN0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lrvGgMti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_jqITEXB8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zVgbADQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lrvGgMti_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jqITEXB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6UZdg3nT, HV_BINOP_DIVIDE, 0, m, &cBinop_6UZdg3nT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IieKGfN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zVgbADQz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6UZdg3nT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qI9rWCOF, HV_BINOP_MULTIPLY, 1, m, &cBinop_qI9rWCOF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qI9rWCOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AjOwWSs6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_axHHWgME_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_x2Swfm5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dXTfW897_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_xRbqbfef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ofbPZUvv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XHg4rDrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WaAfeT2Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WaAfeT2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qI9rWCOF, HV_BINOP_MULTIPLY, 0, m, &cBinop_qI9rWCOF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_deGkjpTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ynCh7tSK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ynCh7tSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hkAlh6Bw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JxB9x6Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WyOhiDV1, HV_BINOP_MULTIPLY, 1, m, &cBinop_WyOhiDV1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8JTaWSxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sgmO2Ohc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sgmO2Ohc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JxB9x6Hi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_N0Gd6HCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ln2wqx49_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ln2wqx49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIst5pni, HV_BINOP_MULTIPLY, 1, m, &cBinop_VIst5pni_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2gvBywhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KvbQ8Ldn, HV_BINOP_MULTIPLY, 1, m, &cBinop_KvbQ8Ldn_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uGDCrOM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TEa7ex51_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TEa7ex51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2gvBywhU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9eciTNOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aMgnu3yG, 1, m, &cVar_aMgnu3yG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DN8TdhTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H9kJRyie, HV_BINOP_MULTIPLY, 1, m, &cBinop_H9kJRyie_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Lk6CNCPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u5d9tByK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u5d9tByK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_icHixfCO, HV_BINOP_MULTIPLY, 1, m, &cBinop_icHixfCO_sendMessage);
}

void Heavy_WSTD_EQ::cVar_aMgnu3yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nnoK3x74_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_DSHMvt3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EEJUWKM4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XHg4rDrO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H0azVfFK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ZmvDL3Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_deGkjpTb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AjOwWSs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_x2Swfm5k_sendMessage);
}

void Heavy_WSTD_EQ::cCast_axHHWgME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xRbqbfef_sendMessage);
}

void Heavy_WSTD_EQ::cSend_dXTfW897_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bVBKrPX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ofbPZUvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e14VlplK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JnDWdxjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tCatBsZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hkAlh6Bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jfWXp3Qe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jfWXp3Qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QuXk2WN, HV_BINOP_MULTIPLY, 1, m, &cBinop_1QuXk2WN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1QuXk2WN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zFAFq9Lb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zFAFq9Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JnDWdxjl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nnoK3x74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_K7TUvW9h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K7TUvW9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBGX1Xvd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IRWFBsH5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qMUBiClp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrHaSWp7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5QSphbkG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QBiCWPDv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WyOhiDV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtwxzOxS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VIst5pni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XjCu0VJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KvbQ8Ldn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ZCPRHYj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_H9kJRyie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UaZsGr0M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_icHixfCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pgz7n11D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_IzbrIApp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DSHMvt3u, 0, m, &cVar_DSHMvt3u_sendMessage);
}

void Heavy_WSTD_EQ::cCast_L79fs7AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZmvDL3Ko, 1, m, &cVar_ZmvDL3Ko_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5QSphbkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIst5pni, HV_BINOP_MULTIPLY, 0, m, &cBinop_VIst5pni_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qMUBiClp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H9kJRyie, HV_BINOP_MULTIPLY, 0, m, &cBinop_H9kJRyie_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lrHaSWp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KvbQ8Ldn, HV_BINOP_MULTIPLY, 0, m, &cBinop_KvbQ8Ldn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IRWFBsH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_icHixfCO, HV_BINOP_MULTIPLY, 0, m, &cBinop_icHixfCO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QBiCWPDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WyOhiDV1, HV_BINOP_MULTIPLY, 0, m, &cBinop_WyOhiDV1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wBGX1Xvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_EEJUWKM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZmvDL3Ko, 0, m, &cVar_ZmvDL3Ko_sendMessage);
}

void Heavy_WSTD_EQ::cCast_H0azVfFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aMgnu3yG, 0, m, &cVar_aMgnu3yG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uJuKdr5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m32mDuPC, 1, m, &cIf_m32mDuPC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3CiN0xnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_08Ze1Dn4, m);
}

void Heavy_WSTD_EQ::cBinop_BpqDTW7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3CiN0xnb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2cst7dhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m32mDuPC, 0, m, &cIf_m32mDuPC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_mm4wg3KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gfhUPlb, HV_BINOP_DIVIDE, 0, m, &cBinop_2gfhUPlb_sendMessage);
}

void Heavy_WSTD_EQ::cVar_JV3PxlOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0K23buCf, HV_BINOP_DIVIDE, 1, m, &cBinop_0K23buCf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gfhUPlb, HV_BINOP_DIVIDE, 1, m, &cBinop_2gfhUPlb_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YsfYWJhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pLaqULkr, HV_BINOP_DIVIDE, 0, m, &cBinop_pLaqULkr_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xQEriZi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pLaqULkr, HV_BINOP_DIVIDE, 1, m, &cBinop_pLaqULkr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jsDfF9db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JV3PxlOg, 0, m, &cVar_JV3PxlOg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bSlPDTYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0K23buCf, HV_BINOP_DIVIDE, 0, m, &cBinop_0K23buCf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AnAVIFMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mm4wg3KK, 0, m, &cVar_mm4wg3KK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0K23buCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_YsfYWJhv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2gfhUPlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_xQEriZi5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pLaqULkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qAsihnSu_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_iOwX99U5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_jJZcs8a5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3tHwTXK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_aD298d2I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qAsihnSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3tHwTXK4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aD298d2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_iOwX99U5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jJZcs8a5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9n4zQu4j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wqHgOIYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GAdbXhTd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Uq0XcwsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_q7G75aA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GAdbXhTd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Uq0XcwsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_trJ6z90N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GAdbXhTd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Uq0XcwsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dzzEwIvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GAdbXhTd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Uq0XcwsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9n4zQu4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GAdbXhTd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Uq0XcwsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9VmjTcOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XLivK4yo, 0, m, &cVar_XLivK4yo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jWqNZ73T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_P8zTRe4S, 0, m, &cVar_P8zTRe4S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xzovZCcn, 0, m, &cVar_xzovZCcn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_25i8kIBw, 0, m, &cVar_25i8kIBw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KMsYOIpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P8zTRe4S, 0, m, &cVar_P8zTRe4S_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Ybba6zfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xzovZCcn, 0, m, &cVar_xzovZCcn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Sq9k2xqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_25i8kIBw, 0, m, &cVar_25i8kIBw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1TEGd9G7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vDjpRPa0, 0, m, &cVar_vDjpRPa0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YfygsoHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ccQqrDjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P4p5lmps_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_yo0yF3ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2optDNnF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1XHO7aT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JPg1lWXr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_igvhVmWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_axRGJZTJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSQ7NV4M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PoF6lTnq_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pq0fiBPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lku0hxk9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zyxKkxLB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zsCK6Wqc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bhSlk7fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_76KexZyH_sendMessage(_c, 0, m);
  cMsg_FYamITiA_sendMessage(_c, 0, m);
  cMsg_eD4di4nM_sendMessage(_c, 0, m);
  cMsg_faUdqUa5_sendMessage(_c, 0, m);
  cMsg_t8pU3qyU_sendMessage(_c, 0, m);
  cMsg_EJkEM8bC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eIFztZDJ, 0, m, &cVar_eIFztZDJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vDjpRPa0, 0, m, &cVar_vDjpRPa0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r9bkVIHD, 0, m, &cVar_r9bkVIHD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lXMhDqlF, 0, m, &cVar_lXMhDqlF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hh1tb3PN, 0, m, &cVar_Hh1tb3PN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DSHMvt3u, 0, m, &cVar_DSHMvt3u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3IVzgAfr, 0, m, &cVar_3IVzgAfr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AoMvPUFv, 0, m, &cVar_AoMvPUFv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ee1UGGEo, 0, m, &cVar_ee1UGGEo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1Hp9i8ZP, 0, m, &cVar_1Hp9i8ZP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B0BY5fhN, 0, m, &cVar_B0BY5fhN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oRMQpLQq, 0, m, &cVar_oRMQpLQq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pizACLpA, 0, m, &cVar_pizACLpA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hhW81AFE, 0, m, &cVar_hhW81AFE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DrW5TBfa, 0, m, &cVar_DrW5TBfa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C1WLcOZB, 0, m, &cVar_C1WLcOZB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nFlHxJnt, 0, m, &cVar_nFlHxJnt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cx180ZdU, 0, m, &cVar_cx180ZdU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LEG1VUKd, 0, m, &cVar_LEG1VUKd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9HkK8sZj, 0, m, &cVar_9HkK8sZj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5UiwPlYA, 0, m, &cVar_5UiwPlYA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KcaDshVq, 0, m, &cVar_KcaDshVq_sendMessage);
  cMsg_jWqNZ73T_sendMessage(_c, 0, m);
  cMsg_9VmjTcOg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_soPsQjtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQO63okX, HV_BINOP_MULTIPLY, 0, m, &cBinop_PQO63okX_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_vPjwuvHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HRdxhAnK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QHEWK9R2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GgVM9jLw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_phTHHpTl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0KzfHi9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tWq6NAMg_sendMessage);
  cMsg_CNWmONzR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_m5e7Aq39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZtfF0nUO, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZtfF0nUO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_SiERvPgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_FBGEm8RO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hdxZfauI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llnX3u10, HV_BINOP_MULTIPLY, 1, m, &cBinop_llnX3u10_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oxcWVamM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pHcSUrPc_sendMessage);
  cMsg_JEkpUsvT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_yC8LpLLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGOCgWrI, HV_BINOP_MULTIPLY, 0, m, &cBinop_UGOCgWrI_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lquXcDOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8zYlXTY5_sendMessage(_c, 0, m);
  cMsg_ac47BNNs_sendMessage(_c, 0, m);
  cMsg_i3kI5xWo_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_UfCK1V8n_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IJU3i5SG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7UAgDHu9_sendMessage);
  cMsg_G4kVtFQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_GhYqeCIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hh1tb3PN, 0, m, &cVar_Hh1tb3PN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tUDVZbcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8FZZv6Fe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IlfFVuSU_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5XRiVZMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASqvjHWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JPq5abLk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_auq8VMWF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Bfy3t6Ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zo2Qz3qO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pUXEmVPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4JYQuTbo_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bKASk7QB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eG9Lp893_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dDhPTzbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sYCihrcE_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sDNPnFrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upAeqqDS, HV_BINOP_MULTIPLY, 0, m, &cBinop_upAeqqDS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_3Gqoqpft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wrZlon2x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Svc98wcC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HfXplvYv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_XVJAJIL5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_46iclud7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jDmT6WAz_sendMessage);
  cMsg_Q1LJzXVA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_dhBjdEc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ow9jJSJn, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ow9jJSJn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UGvLs6b1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_RFPZNCYK_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_TP1M86va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRUW7Sx0, HV_BINOP_MULTIPLY, 1, m, &cBinop_DRUW7Sx0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1kDM4T0O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4MahBPoq_sendMessage);
  cMsg_Sych993x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_bVBKrPX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QuXk2WN, HV_BINOP_MULTIPLY, 0, m, &cBinop_1QuXk2WN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_e14VlplK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8JTaWSxX_sendMessage(_c, 0, m);
  cMsg_N0Gd6HCa_sendMessage(_c, 0, m);
  cMsg_uGDCrOM1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DN8TdhTI_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tCatBsZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9eciTNOU_sendMessage);
  cMsg_Lk6CNCPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_1eenD5T2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XLivK4yo, 0, m, &cVar_XLivK4yo_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_gHTTdIFR, VOf(Bf0));
    __hv_varread_f(&sVarf_qI5GHpx4, VOf(Bf1));
    __hv_varread_f(&sVarf_IyULZQlq, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HYrtBFHo, VOf(Bf0));
    __hv_varread_f(&sVarf_RvHkeihk, VOf(Bf1));
    __hv_varread_f(&sVarf_B0E39dyv, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_pZ3WUhIk, VOf(Bf0));
    __hv_line_f(&sLine_mZznvB9g, VOf(Bf1));
    __hv_line_f(&sLine_bbtBN6d2, VOf(Bf4));
    __hv_line_f(&sLine_IEDzMTHs, VOf(Bf5));
    __hv_line_f(&sLine_IJW2SQCq, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_jV07Hw1U, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_N2m7hpUP, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_IG1ZO7FY, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_o7AxAX61, VOf(Bf1));
    __hv_line_f(&sLine_gvcjVKkX, VOf(Bf0));
    __hv_line_f(&sLine_lr0UWOT6, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_OhzeUZxJ, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_RVIKx4O1, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_3Oj3emeJ, VOf(Bf7));
    __hv_line_f(&sLine_XyD5jdhA, VOf(Bf1));
    __hv_line_f(&sLine_Cdl7DZwy, VOf(Bf4));
    __hv_line_f(&sLine_MB7I3zxQ, VOf(Bf6));
    __hv_line_f(&sLine_fBRRsgcS, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_awuFV6wN, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_fgRza7gZ, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_gHTTdIFR, VIf(Bf5));
    __hv_varwrite_f(&sVarf_qI5GHpx4, VIf(Bf0));
    __hv_varwrite_f(&sVarf_IyULZQlq, VIf(Bf6));
    __hv_line_f(&sLine_RyQaImDd, VOf(Bf6));
    __hv_line_f(&sLine_gX9RJkcz, VOf(Bf0));
    __hv_line_f(&sLine_Q2MeyglR, VOf(Bf5));
    __hv_line_f(&sLine_2k42GY5k, VOf(Bf8));
    __hv_line_f(&sLine_sxnaJbui, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_bG9H9qF9, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_VVnBcrur, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_O0RVZWsg, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_6WhiIPzd, VOf(Bf0));
    __hv_line_f(&sLine_ic76AI5J, VOf(Bf6));
    __hv_line_f(&sLine_bpT4wfnQ, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_OoDIWNmd, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_08Ze1Dn4, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_RyvkNURZ, VOf(Bf1));
    __hv_line_f(&sLine_PG2X2Ujs, VOf(Bf0));
    __hv_line_f(&sLine_DCENHStM, VOf(Bf5));
    __hv_line_f(&sLine_RdcCFiRv, VOf(Bf4));
    __hv_line_f(&sLine_E5ZJNniV, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_LlW4Eixp, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_6l7Ed3qZ, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_HYrtBFHo, VIf(Bf8));
    __hv_varwrite_f(&sVarf_RvHkeihk, VIf(Bf6));
    __hv_varwrite_f(&sVarf_B0E39dyv, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
